@@ -1,4 +1,4 @@
-from pygeoinf.random_matrix import (
+from .random_matrix import (
     fixed_rank_random_range,
     variable_rank_random_range,
     random_svd,
@@ -6,20 +6,32 @@ from pygeoinf.random_matrix import (
     random_cholesky,
 )
 
-from pygeoinf.hilbert_space import (
+from .hilbert_space import (
     HilbertSpace,
+    DualHilbertSpace,
     EuclideanSpace,
+    HilbertModule,
+    MassWeightedHilbertSpace,
+    MassWeightedHilbertModule,
+)
+
+
+from .operators import (
     Operator,
     LinearOperator,
     DiagonalLinearOperator,
+)
+
+from .linear_forms import (
     LinearForm,
 )
 
-from pygeoinf.gaussian_measure import (
+
+from .gaussian_measure import (
     GaussianMeasure,
 )
 
-from pygeoinf.direct_sum import (
+from .direct_sum import (
     HilbertSpaceDirectSum,
     BlockStructure,
     BlockLinearOperator,
@@ -28,7 +40,7 @@ from pygeoinf.direct_sum import (
     BlockDiagonalLinearOperator,
 )
 
-from pygeoinf.linear_solvers import (
+from .linear_solvers import (
     LinearSolver,
     DirectLinearSolver,
     LUSolver,
@@ -41,13 +53,11 @@ from pygeoinf.linear_solvers import (
     CGSolver,
 )
 
-from pygeoinf.forward_problem import ForwardProblem, LinearForwardProblem
+from .forward_problem import ForwardProblem, LinearForwardProblem
 
-from pygeoinf.optimisation import (
+from .linear_optimisation import (
     LinearLeastSquaresInversion,
     LinearMinimumNormInversion,
 )
 
-from pygeoinf.bayesian import LinearBayesianInversion, LinearBayesianInference
-
-from pygeoinf.checks.hilbert_space import HilbertSpaceChecks
+from .linear_bayesian import LinearBayesianInversion, LinearBayesianInference
